Index: src/main.c
===================================================================
--- src/main.c	(revision 2247)
+++ src/main.c	(working copy)
@@ -112,6 +112,7 @@
 #ifdef HAVE_PLUGINS
 static gboolean no_plugins = FALSE;
 #endif
+static gboolean dummy = FALSE;
 
 // in alphabetical order of short options
 static GOptionEntry entries[] =
@@ -139,6 +140,7 @@
 	{ "vte-lib", 0, 0, G_OPTION_ARG_FILENAME, &lib_vte, N_("Filename of libvte.so"), NULL },
 #endif
 	{ "version", 'v', 0, G_OPTION_ARG_NONE, &show_version, N_("Show version and exit"), NULL },
+	{ "dummy", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &dummy, NULL, NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
@@ -365,6 +367,56 @@
 }
 
 
+/* get a :line:column specifier from the end of a filename (if present),
+ * return the line/column values, and remove the specifier from the string
+ * (Note that *line and *column must both be set to -1 initially) */
+static void get_line_and_column_from_filename(gchar *filename, gint *line, gint *column)
+{
+	gsize i;
+	gint colon_count = 0;
+	gboolean have_number = FALSE;
+
+	g_assert(*line == -1 && *column == -1);
+
+	if (!NZV(filename))
+		return;
+
+	for (i = strlen(filename) - 1; i >= 1; i--)
+	{
+		gboolean is_colon = filename[i] == ':';
+		gboolean is_digit = g_ascii_isdigit(filename[i]);
+
+		if (!is_colon && !is_digit)
+			break;
+
+		if (is_colon)
+		{
+			if (++colon_count > 1)
+				break;	/* bail on 2+ colons in a row */
+		}
+		else
+			colon_count = 0;
+
+		if (is_digit)
+			have_number = TRUE;
+
+		if (is_colon && have_number)
+		{
+			gint number = atoi(&filename[i + 1]);
+
+			filename[i] = '\0';
+			have_number = FALSE;
+
+			*column = *line;
+			*line = number;
+		}
+
+		if (*column >= 0)
+			break;	/* line and column are set, so we're done */
+	}
+}
+
+
 static void setup_paths()
 {
 	gchar *data_dir;
@@ -424,6 +476,23 @@
 {
 	GError *error = NULL;
 	GOptionContext *context;
+	gint i;
+
+	/* first initialise cl_options fields with default values */
+	cl_options.load_session = TRUE;
+	cl_options.goto_line = -1;
+	cl_options.goto_column = -1;
+
+	/* the GLib option parser can't handle the +NNN (line number)
+	 * option, so we grab that here and replace it with a no-op */
+	for (i = 1; i < *argc; i++)
+	{
+		if ((*argv)[i][0] != '+')
+			continue;
+
+		cl_options.goto_line = atoi(&(*argv)[i][1]);
+		(*argv)[i] = "--dummy";
+	}
 
 	context = g_option_context_new(_("[FILES...]"));
 	g_option_context_add_main_entries(context, entries, GETTEXT_PACKAGE);
@@ -432,11 +501,6 @@
 	g_option_context_parse(context, argc, argv, &error);
 	g_option_context_free(context);
 
-	// first initialise cl_options fields with default values
-	cl_options.load_session = TRUE;
-	cl_options.goto_line = -1;
-	cl_options.goto_column = -1;
-
 	if (error != NULL)
 	{
 		g_printerr("Geany: %s\n", error->message);
@@ -520,8 +584,6 @@
 
 	if (ft_names)
 	{
-		int i;
-
 		printf("Geany's internal filetype names:\n");
 		filetypes_init_types();
 		for (i = 0; i < GEANY_MAX_FILE_TYPES; i++)
@@ -597,6 +659,17 @@
 	{
 		gchar *filename = get_argv_filename(argv[i]);
 
+		if (filename != NULL)
+		{
+			gint line = -1, column = -1;
+
+			get_line_and_column_from_filename(filename, &line, &column);
+			if (line >= 0)
+				cl_options.goto_line = line;
+			if (column >= 0)
+				cl_options.goto_column = column;
+		}
+
 		if (filename != NULL &&
 			g_file_test(filename, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_IS_SYMLINK))
 		{
